from setuptools import setup

setup(
  name='zwc',
  version='0.1.0',
  description='Chinese word count tool',
  long_description='This is a simple Chinese word count tool that contains a command line program and a Python module.',
  url='https://github.com/physacco/zwc',
  author='physacco',
  author_email='physacco@gmail.com',
  license='MIT',
  py_modules=['zwc'],
  scripts=['zwc']
)
